@@ -1,9 +1,9 @@
 /*
  * list.h
  * 
- * Version:       0.1.2
+ * Version:       0.2.0
  * 
- * Release date:  25.09.2015
+ * Release date:  15.11.2015
  * 
  * Copyright 2015 Vladimir (sodoma) Gozora <c@gozora.sk>
  * 
@@ -26,8 +26,10 @@
  */
 
 #include "globals.h"
+#include "unistd.h"
 
 extern uint8_t filename_convert_name(char *input, char *output, enum conv_type_l type);
+extern int option_on_off(uint32_t option2check, enum opt_l option);
 
 /* ebiso.c */
 int list_create(const char *dirname, struct file_list_t **flist, struct ISO_data_t *ISO_data);
